#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const csvParser = require("csv-parser");
const execPromise = require("exec-promise");
const through2 = require("through2");
const xo_lib_1 = require("xo-lib");
const parseBoolean = (value, defaultValue) => {
    if (value === undefined || value === '') {
        return defaultValue;
    }
    const lcValue = value.toLocaleLowerCase();
    if (value === '0' || lcValue === 'false') {
        return false;
    }
    if (value === '1' || lcValue === 'true') {
        return true;
    }
    throw new Error(`invalid boolean value: ${value}`);
};
const requiredParam = (name) => {
    throw `missing param: ${name}

Usage: xo-import-servers-csv $url $username $password < $csvFile`;
};
execPromise(([url = requiredParam('url'), username = requiredParam('username'), password = requiredParam('password')]) => __awaiter(this, void 0, void 0, function* () {
    const xo = new xo_lib_1.default({ url });
    yield xo.open();
    yield xo.signIn({ username, password });
    console.log('connected as', xo.user.email);
    const errors = [];
    const stream = process.stdin
        .pipe(csvParser())
        .pipe(through2.obj(({ allowUnauthorized, autoConnect, host, label, password, username, }, _, next) => {
        console.log('server', host);
        xo.call('server.add', {
            allowUnauthorized: parseBoolean(allowUnauthorized),
            autoConnect: parseBoolean(autoConnect, false),
            host,
            label,
            password,
            username
        }).then(() => next(), (error) => {
            errors.push({ host, error });
            return next();
        });
    }));
    yield new Promise((resolve, reject) => {
        stream.on('error', reject);
        stream.on('finish', resolve);
    });
    if (errors.length) {
        console.error(errors);
    }
}));
//# sourceMappingURL=index.js.map